Learn R Programming

pretestcad (version 1.1.0)

arg_match0_allow_na: Match an argument to a character vector but skip NA

Description

This is equivalent to arg_match but skip NA

Usage

arg_match0_allow_na(
  arg,
  values,
  arg_nm = rlang::caller_arg(arg),
  error_call = rlang::caller_env()
)

Value

The string supplied to arg.

Arguments

arg

A symbol referring to an argument accepting strings.

values

A character vector of possible values that arg can take.

arg_nm

Same as error_arg.

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

See Also

Examples

Run this code
# No error
input = "male"
arg_match0_allow_na(input, values = c("female","male"))

# Allow NA
input = NA
arg_match0_allow_na(input, values = c("female","male"))

# Error as M is not female or male
input = "emale"
try(arg_match0_allow_na(input, values = c("female","male")))

Run the code above in your browser using DataLab