Calculate 2011 CAD1 Basic PTP for obstructive CAD
Source:R/cad_consortium_ptp.R
calculate_cad1_2011_ptp.RdThis function returns a patient's pre-test probability (PTP) of obstructive coronary artery disease (CAD) based on the 2011 CAD Consortium 1 (CAD1) basic model. Obstructive CAD was defined as a stenosis causing \(\geq\) 50% diameter stenosis on coronary CTA.
Arguments
- age
Input numeric value to indicate the age of the patient in years.
- sex
The value of variable in the parameters
label_sex_male,label_sex_femaleandlabel_sex_unknown.- chest_pain_type
The value of variable in the parameters,
label_cpt_nonanginal,label_cpt_atypical,label_cpt_typicalandlabel_cpt_unknown.- label_sex_male
Label(s) for definition(s) of male sex. Default:
c("male")- label_sex_female
Label(s) for definition(s) of female sex. Default:
c("female")- label_sex_unknown
Label(s) for definition(s) of missing sex. Default:
c(NA, NaN)- label_cpt_nonanginal
Label(s) for patient having nonanginal or non-specific chest pain.
Default:c("nonanginal")- label_cpt_atypical
Label(s) for patient having atypical chest pain. Default:
c("atypical")- label_cpt_typical
Label(s) for patient having typical chest pain. Default:
c("typical")- label_cpt_unknown
Label(s) for patient having unknown chest pain type symptoms. Default:
c(NA, NaN)
Value
A numeric value representing the patient's PTP for obstructive CAD based on the 2011 CAD Consortium 1 (CAD1) basic model.
Details
The predictive model is based on patients from 14 hospitals in Europe and the United States.
This model is also called the updated Diamond-Forrester model. Model formula used is from Table 3.
It is of the form $$\frac{1}{(1 + e^{-F(x)})}$$ where \(F(x)\) equals $$ \begin{array}{l} -4.37\quad+ \\\\ (0.04 * age)\quad+ \\\\ (1.34 * sex\_is\_male)\quad+ \\\\ (1.91 * have\_typical\_chest\_pain)\quad+ \\\\ (0.64 * have\_atypical\_chest\_pain) \end{array} $$