This function returns a patient's pre-test probability (PTP) of obstructive coronary artery disease based on the 2012 CAD Consortium 2 (CAD2) clinical model.
calculate_cad2_2012_clinical_ptp(
age,
sex,
chest_pain_type,
have_diabetes,
have_hypertension,
have_dyslipidemia,
have_smoking_history,
label_sex_male = c("male"),
label_sex_female = c("female"),
label_sex_unknown = c(NA, NaN),
label_cpt_nonanginal = c("nonanginal"),
label_cpt_atypical = c("atypical"),
label_cpt_typical = c("typical"),
label_cpt_unknown = c(NA, NaN),
label_have_diabetes_no = c("no"),
label_have_diabetes_yes = c("yes"),
label_have_diabetes_unknown = c(NA, NaN),
label_have_hypertension_no = c("no"),
label_have_hypertension_yes = c("yes"),
label_have_hypertension_unknown = c(NA, NaN),
label_have_dyslipidemia_no = c("no"),
label_have_dyslipidemia_yes = c("yes"),
label_have_dyslipidemia_unknown = c(NA, NaN),
label_have_smoking_history_no = c("no"),
label_have_smoking_history_yes = c("yes"),
label_have_smoking_history_unknown = c(NA, NaN)
)A numeric value representing the patient's PTP for obstructive CAD based on the 2012 CAD Consortium 2 (CAD2) clinical model.
Input numeric value to indicate the age of the patient in years.
The value of variable in the parameters label_sex_male,
label_sex_female and label_sex_unknown.
The value of variable in the parameters,
label_cpt_nonanginal, label_cpt_atypical, label_cpt_typical and
label_cpt_unknown.
The value of variable in the parameters
label_have_diabetes_no, label_have_diabetes_yes
and label_have_diabetes_unknown.
The value of variable in the parameters
label_have_hypertension_no, label_have_hypertension_yes
and label_have_hypertension_unknown.
The value of variable in the parameters
label_have_dyslipidemia_no, label_have_dyslipidemia_yes
and label_have_dyslipidemia_unknown.
The value of variable in the parameters
label_have_smoking_history_no, label_have_smoking_history_yes
and label_have_smoking_history_unknown.
Label(s) for definition(s) of male sex.
Default: c("male")
Label(s) for definition(s) of female sex.
Default: c("female")
Label(s) for definition(s) of missing sex.
Default: c(NA, NaN)
Label(s) for patient having nonanginal or non-specific chest pain.
Default: c("nonanginal")
Label(s) for patient having atypical chest pain.
Default: c("atypical")
Label(s) for patient having typical chest pain.
Default: c("typical")
Label(s) for patient having unknown chest pain type symptoms.
Default: c(NA, NaN)
Label(s) for patient with no diabetes.
Default: c("no")
Label(s) for patient having diabetes.
Default: c("yes")
Label(s) for patient
having unknown diabetes.
Default: c(NA, NaN)
Label(s) for patient with no hypertension.
Default: c("no")
Label(s) for patient having hypertension.
Default: c("yes")
Label(s) for patient
having unknown hypertension.
Default: c(NA, NaN)
Label(s) for patient with no dyslipidemia.
Default: c("no")
Label(s) for patient having dyslipidemia.
Default: c("yes")
Label(s) for patient
having unknown dyslipidemia.
Default: c(NA, NaN)
Label(s) for patient with
no smoking history (current or past).
Default: c("no")
Label(s) for patient having
smoking history (current or past).
Default: c("yes")
Label(s) for patient
having unknown smoking history (current or past).
Default: c(NA, NaN)
The predictive model is based on patients from 18 hospitals in Europe and the United States.
# 40 year old female with typical chest pain,
# diabetes but no hypertension, dyslipidemia
# and a non-smoker
calculate_cad2_2012_clinical_ptp(
age = 40,
sex = "female",
chest_pain_type = "typical",
have_diabetes = "yes",
have_hypertension = "no",
have_dyslipidemia = "no",
have_smoking_history = "no"
)
Run the code above in your browser using DataLab