This function returns a patient's pre-test probability (PTP) of significant (>75% luminal diameter narrowing of at least one major coronary artery) coronary artery disease based on the 1993 Duke Clinical Score.
calculate_dcs_1993_sig_cad_ptp(
age,
sex,
chest_pain_type,
have_mi,
have_smoking_history,
have_dyslipidemia,
have_diabetes,
have_q_waves,
have_st_t_changes,
label_sex_male = c("male"),
label_sex_female = c("female"),
label_sex_unknown = c(NA, NaN),
label_cpt_nonanginal = c("nonanginal"),
label_cpt_atypical = c("atypical"),
label_cpt_typical = c("typical"),
label_cpt_unknown = c(NA, NaN),
label_have_mi_no = c("no"),
label_have_mi_yes = c("yes"),
label_have_mi_unknown = c(NA, NaN),
label_have_smoking_history_no = c("no"),
label_have_smoking_history_yes = c("yes"),
label_have_smoking_history_unknown = c(NA, NaN),
label_have_dyslipidemia_no = c("no"),
label_have_dyslipidemia_yes = c("yes"),
label_have_dyslipidemia_unknown = c(NA, NaN),
label_have_diabetes_no = c("no"),
label_have_diabetes_yes = c("yes"),
label_have_diabetes_unknown = c(NA, NaN),
label_have_q_waves_no = c("no"),
label_have_q_waves_yes = c("yes"),
label_have_q_waves_unknown = c(NA, NaN),
label_have_st_t_changes_no = c("no"),
label_have_st_t_changes_yes = c("yes"),
label_have_st_t_changes_unknown = c(NA, NaN)
)A numeric value representing the patient's PTP for significant (>75% luminal diameter narrowing of at least one major coronary artery) CAD based on the 1993 Duke Clinical Score.
Input numeric value to indicate the age of the patient in years.
The value of variable in the parameters label_sex_male,
label_sex_female and label_sex_unknown.
The value of variable in the parameters,
label_cpt_nonanginal, label_cpt_atypical, label_cpt_typical and
label_cpt_unknown.
The value of variable in the parameters
label_have_mi_no, label_have_mi_yes
and label_have_mi_unknown.
The value of variable in the parameters
label_have_smoking_history_no, label_have_smoking_history_yes
and label_have_smoking_history_unknown.
The value of variable in the parameters
label_have_dyslipidemia_no, label_have_dyslipidemia_yes
and label_have_dyslipidemia_unknown.
The value of variable in the parameters
label_have_diabetes_no, label_have_diabetes_yes
and label_have_diabetes_unknown.
The value of variable in the parameters
label_have_q_waves_no, label_have_q_waves_yes
and label_have_q_waves_unknown.
The value of variable in the parameters
label_have_st_t_changes_no, label_have_st_t_changes_yes
and label_have_st_t_changes_unknown.
Label(s) for definition(s) of male sex.
Default: c("male")
Label(s) for definition(s) of female sex.
Default: c("female")
Label(s) for definition(s) of missing sex.
Default: c(NA, NaN)
Label(s) for patient having nonanginal or non-specific chest pain.
Default: c("nonanginal")
Label(s) for patient having atypical chest pain.
Default: c("atypical")
Label(s) for patient having typical chest pain.
Default: c("typical")
Label(s) for patient having unknown chest pain type symptoms.
Default: c(NA, NaN)
Label(s) for patient not having a previous history of MI.
Default: c("no")
Label(s) for patient having a previous history of MI.
Default: c("yes")
Label(s) for patient with unknown previous history of MI.
Default: c(NA, NaN)
Label(s) for patient with
no smoking history (current or past).
Default: c("no")
Label(s) for patient having
smoking history (current or past).
Default: c("yes")
Label(s) for patient
having unknown smoking history (current or past).
Default: c(NA, NaN)
Label(s) for patient with no dyslipidemia.
Default: c("no")
Label(s) for patient having dyslipidemia.
Default: c("yes")
Label(s) for patient
having unknown dyslipidemia.
Default: c(NA, NaN)
Label(s) for patient with no diabetes.
Default: c("no")
Label(s) for patient having diabetes.
Default: c("yes")
Label(s) for patient
having unknown diabetes.
Default: c(NA, NaN)
Label(s) for patient not having Q waves on ECG.
Default: c("no")
Label(s) for patient having Q waves on ECG.
Default: c("yes")
Label(s) for patient with unknown Q waves on ECG.
Default: c(NA, NaN)
Label(s) for patient not having ST-T changes on ECG.
Default: c("no")
Label(s) for patient having ST-T changes on ECG.
Default: c("yes")
Label(s) for patient with unknown ST-T changes on ECG.
Default: c(NA, NaN)
The predictive model is based on patients referred for cardiac catheterisation between 1969 and 1983.
# 40 year old female with typical chest pain,
# previous history of MI,
# has diabetes but no dyslipidemia and a non-smoker.
# She has Q waves but no ST-T changes on ECG.
calculate_dcs_1993_sig_cad_ptp(
age = 40,
sex = "female",
chest_pain_type = "typical",
have_mi = "yes",
have_smoking_history = "no",
have_dyslipidemia = "no",
have_diabetes = "yes",
have_q_waves = "yes",
have_st_t_changes = "no"
)
Run the code above in your browser using DataLab