Calculate 2023 Miller PTP for obstructive CAD (stenosis \(\geq\) 50% in left main vessel or \(\geq\) 70% in non-left main vessel)
Source:R/miller_ptp.R
calculate_miller_2023_lm_50_non_lm_70_cad_ptp.RdThis function returns a patient's pre-test Probability (PTP) of obstructive coronary artery disease (CAD) based on 2023 Miller et. al. likelihood table likelihood table for CAD (stenosis \(\geq\) 50% in left main vessel or \(\geq\) 70% in non-left main vessel).
Usage
calculate_miller_2023_lm_50_non_lm_70_cad_ptp(
age,
sex,
have_chest_pain,
coronary_calcium_score,
output = c("grouping", "numeric", "percentage"),
label_sex_male = c("male"),
label_sex_female = c("female"),
label_sex_unknown = c(NA, NaN),
label_have_chest_pain_no = c("no"),
label_have_chest_pain_yes = c("yes"),
label_have_chest_pain_unknown = c(NA, NaN),
error_call = rlang::caller_env()
)Arguments
- age
Input integer value to indicate the age of the patient in years.
- sex
The value of variable in the parameters
label_sex_male,label_sex_femaleandlabel_sex_unknown.- have_chest_pain
The value of variable in the parameters
label_have_chest_pain_no,label_have_chest_pain_yes,
andlabel_have_chest_pain_unknown.- coronary_calcium_score
Input non-negative numeric to indicate the total coronary calcium score of the patient.
- output
Input text to indicate the how pre-test probability results be expressed Default: c("grouping", "numeric", "percentage")
grouping means the PTP will be expressed as Low, Intermediate and High.
low if PTP is less than 15%.
intermediate if PTP is in between 15% to 50%.
high if PTP is more than 50%.
numeric means the PTP will be expressed as an integer probability (0-100).
percentage means the PTP will be expressed as percentage text (0-100%).
- label_sex_male
Label(s) for definition(s) of male sex. Default:
c("male")- label_sex_female
Label(s) for definition(s) of female sex. Default:
c("female")- label_sex_unknown
Label(s) for definition(s) of missing sex. Default:
c(NA, NaN)- label_have_chest_pain_no
Label(s) for patient not having chest pain symptoms. Default:
c("no")- label_have_chest_pain_yes
Label(s) for patient having chest pain symptoms. Default:
c("yes")- label_have_chest_pain_unknown
Label(s) for patient with unknown chest pain symptoms. Default:
c(NA, NaN)- error_call
The execution environment of a currently running function, e.g.
caller_env(). The function will be mentioned in error messages as the source of the error. See thecallargument ofabort()for more information.
Value
An integer, percentage or category representing the patient's PTP for obstructive CAD
based on 2023 Miller et. al. likelihood table for CAD defined as stenosis \(\geq\) 50% in left main vessel
or \(\geq\) 70% in non-left main vessel.
See parameter option output for more information.