This function returns a patient's pre-test probability (PTP) of obstructive coronary artery disease based on the 2021 Predictive Risk scorE for CAD In Southeast Asians with chEst pain (PRECISE) simple model.
calculate_precise_2021_simple_ptp(
age,
sex,
chest_pain_type,
have_neck_radiation,
have_diabetes,
have_hypertension,
smoking_history_type,
label_sex_male = c("male"),
label_sex_female = c("female"),
label_sex_unknown = c(NA, NaN),
label_cpt_nonanginal = c("nonanginal"),
label_cpt_atypical = c("atypical"),
label_cpt_typical = c("typical"),
label_cpt_unknown = c(NA, NaN),
label_have_neck_radiation_no = c("no"),
label_have_neck_radiation_yes = c("yes"),
label_have_neck_radiation_unknown = c(NA, NaN),
label_have_diabetes_no = c("no"),
label_have_diabetes_yes = c("yes"),
label_have_diabetes_unknown = c(NA, NaN),
label_have_hypertension_no = c("no"),
label_have_hypertension_yes = c("yes"),
label_have_hypertension_unknown = c(NA, NaN),
label_smoking_history_type_current = c("current"),
label_smoking_history_type_past = c("past"),
label_smoking_history_type_none = c("none"),
label_smoking_history_type_unknown = c(NA, NaN)
)A numeric value representing the patient's PTP for obstructive CAD based on the 2021 Predictive Risk scorE for CAD In Southeast Asians with chEst pain (PRECISE) simple model.
Input numeric value to indicate the age of the patient in years.
The value of variable in the parameters label_sex_male,
label_sex_female and label_sex_unknown.
The value of variable in the parameters,
label_cpt_nonanginal, label_cpt_atypical, label_cpt_typical and
label_cpt_unknown.
The value of variable in the parameters
label_have_neck_radiation_no, label_have_neck_radiation_yes
and label_have_neck_radiation_unknown.
The value of variable in the parameters
label_have_diabetes_no, label_have_diabetes_yes
and label_have_diabetes_unknown.
The value of variable in the parameters
label_have_hypertension_no, label_have_hypertension_yes
and label_have_hypertension_unknown.
The value of variable in the parameters
label_smoking_history_type_current, label_smoking_history_type_past,
label_smoking_history_type_none and label_smoking_history_type_unknown
Label(s) for definition(s) of male sex.
Default: c("male")
Label(s) for definition(s) of female sex.
Default: c("female")
Label(s) for definition(s) of missing sex.
Default: c(NA, NaN)
Label(s) for patient having nonanginal or non-specific chest pain.
Default: c("nonanginal")
Label(s) for patient having atypical chest pain.
Default: c("atypical")
Label(s) for patient having typical chest pain.
Default: c("typical")
Label(s) for patient having unknown chest pain type symptoms.
Default: c(NA, NaN)
Label(s) for patient without
chest pain radiating to the neck.
Default: c("no")
Label(s) for patient with
chest pain radiating to the neck.
Default: c("yes")
Label(s) for patient with unknown
chest pain radiating to the neck
Default: c(NA, NaN)
Label(s) for patient with no diabetes.
Default: c("no")
Label(s) for patient having diabetes.
Default: c("yes")
Label(s) for patient
having unknown diabetes.
Default: c(NA, NaN)
Label(s) for patient with no hypertension.
Default: c("no")
Label(s) for patient having hypertension.
Default: c("yes")
Label(s) for patient
having unknown hypertension.
Default: c(NA, NaN)
Label(s) for patient who is a current smoker.
Default: c("current")
Label(s) for patient who is a past smoker.
Default: c("past")
Label(s) for patient who is a non-smoker.
Default: c("none")
Label(s) for patient with unknown smoking history.
Default: c(NA, NaN)
The predictive model is based on patients a mixed Asian cohort within Singapore with stable chest pain.
# 40 year old female with typical chest pain
# radiating to the neck, has diabetes
# but no hypertension and a non-smoker
calculate_precise_2021_simple_ptp(
age = 40,
sex = "female",
chest_pain_type = "typical",
have_neck_radiation = "yes",
have_diabetes = "yes",
have_hypertension = "no",
smoking_history_type = "none"
)
Run the code above in your browser using DataLab