Learn R Programming

pretestcad (version 1.1.0)

chr_quoted: Quoted Characters

Description

Add a quote around characters.

Usage

chr_quoted(chr, type = "`")

Value

A character vector with quotes added in each element. (e.g. c("`a`", "`b`", "`c`")).

Arguments

chr

A character vector to add quotes in each element. (e.g. c("a", "b", "c")).

type

Character to be used as a quote. Default: '`'

Details

DETAILS

Examples

Run this code
chr_quoted(c("a","b", "c"))

Run the code above in your browser using DataLab