This function returns a patient's pre-test probability (PTP) of obstructive coronary artery disease based on the 2011 CAD Consortium 1 (CAD1) basic model.
calculate_cad1_2011_ptp(
age,
sex,
chest_pain_type,
label_sex_male = c("male"),
label_sex_female = c("female"),
label_sex_unknown = c(NA, NaN),
label_cpt_nonanginal = c("nonanginal"),
label_cpt_atypical = c("atypical"),
label_cpt_typical = c("typical"),
label_cpt_unknown = c(NA, NaN)
)A numeric value representing the patient's PTP for obstructive CAD based on the 2011 CAD Consortium 1 (CAD1) basic model.
Input numeric value to indicate the age of the patient in years.
The value of variable in the parameters label_sex_male,
label_sex_female and label_sex_unknown.
The value of variable in the parameters,
label_cpt_nonanginal, label_cpt_atypical, label_cpt_typical and
label_cpt_unknown.
Label(s) for definition(s) of male sex.
Default: c("male")
Label(s) for definition(s) of female sex.
Default: c("female")
Label(s) for definition(s) of missing sex.
Default: c(NA, NaN)
Label(s) for patient having nonanginal or non-specific chest pain.
Default: c("nonanginal")
Label(s) for patient having atypical chest pain.
Default: c("atypical")
Label(s) for patient having typical chest pain.
Default: c("typical")
Label(s) for patient having unknown chest pain type symptoms.
Default: c(NA, NaN)
The predictive model is based on patients from 14 hospitals in Europe and the United States.
This model is also called the updated Diamond-Forrester model.
# 40 year old female with typical chest pain
calculate_cad1_2011_ptp(
age = 40,
sex = "female",
chest_pain_type = "typical"
)
Run the code above in your browser using DataLab