This function returns a patient's pre-test probability (PTP) of obstructive coronary artery disease based on the 2019 Reeh et. al. basic model.
calculate_reeh_2019_basic_ptp(
age,
sex,
symptom_type,
label_sex_male = c("male"),
label_sex_female = c("female"),
label_sex_unknown = c(NA, NaN),
label_symptom_type_typical = c("typical"),
label_symptom_type_atypical = c("atypical"),
label_symptom_type_nonanginal = c("nonanginal"),
label_symptom_type_dyspnoea = c("dyspnoea"),
label_symptom_type_unknown = c(NA, NaN)
)A numeric value representing the patient's PTP for obstructive CAD based on the 2019 Reeh et. al. basic model.
Input numeric value to indicate the age of the patient in years.
The value of variable in the parameters label_sex_male,
label_sex_female and label_sex_unknown.
Input characters (typical, atypical, nonanginal, dyspnoea) to indicate the symptom characteristics of the patient.
typical stands for the patient having typical chest pain.
atypical stands for the patient having atypical chest pain.
nonanginal stands for the patient having nonanginal or non-specific chest pain.
dyspnoea stands for the patient having dyspnoea.
Label(s) for definition(s) of male sex.
Default: c("male")
Label(s) for definition(s) of female sex.
Default: c("female")
Label(s) for definition(s) of missing sex.
Default: c(NA, NaN)
Label(s) for patient having typical chest pain.
Default: c("typical")
Label(s) for patient having atypical chest pain.
Default: c("atypical")
Label(s) for patient having nonanginal
or non-specific chest pain.
Default: c("nonanginal")
Label(s) for patient having dyspnoea.
Default: c("dyspnoea")
Label(s) for patient having unknown symptoms.
Default: c(NA, NaN)
The predictive model is based on 3903 patients free of CAD and heart failure and suspected of angina, who were referred to a single, large, urban university hospital for assessment in 2012–15.
# 40 year old female with typical chest pain
calculate_reeh_2019_basic_ptp(
age = 40,
sex = "female",
symptom_type = "typical"
)
Run the code above in your browser using DataLab