This function returns a patient's pre-test probability (PTP) of obstructive coronary artery disease based on 2020 Winther et. al. Coronary Artery Calcium Score-Weighted Clinical Likelihood (CACS-CL) model.
calculate_winther_2020_cacs_cl_ptp(
age,
sex,
chest_pain_type,
have_dyspnoea,
have_family_history,
have_smoking_history,
have_dyslipidemia,
have_hypertension,
have_diabetes,
coronary_calcium_score,
allow_na_symptom_score = TRUE,
max_na_num_of_rf = 0,
label_sex_male = c("male"),
label_sex_female = c("female"),
label_sex_unknown = c(NA, NaN),
label_have_dyspnoea_no = c("no"),
label_have_dyspnoea_yes = c("yes"),
label_have_dyspnoea_unknown = c(NA, NaN),
label_cpt_no_chest_pain = c("no chest pain"),
label_cpt_nonanginal = c("nonanginal"),
label_cpt_atypical = c("atypical"),
label_cpt_typical = c("typical"),
label_cpt_unknown = c(NA, NaN),
label_have_family_history_no = c("no"),
label_have_family_history_yes = c("yes"),
label_have_family_history_unknown = c(NA, NaN),
label_have_smoking_history_no = c("no"),
label_have_smoking_history_yes = c("yes"),
label_have_smoking_history_unknown = c(NA, NaN),
label_have_dyslipidemia_no = c("no"),
label_have_dyslipidemia_yes = c("yes"),
label_have_dyslipidemia_unknown = c(NA, NaN),
label_have_hypertension_no = c("no"),
label_have_hypertension_yes = c("yes"),
label_have_hypertension_unknown = c(NA, NaN),
label_have_diabetes_no = c("no"),
label_have_diabetes_yes = c("yes"),
label_have_diabetes_unknown = c(NA, NaN)
)A numeric value representing the patient's PTP for obstructive CAD based on the 2020 Winther et. al. Coronary Artery Calcium Score-Weighted Clinical Likelihood (CACS-CL) model.
Input numeric value to indicate the age of the patient in years.
The value of variable in the parameters label_sex_male,
label_sex_female and label_sex_unknown.
The value of variable in the parameters label_cpt_no_chest_pain,
label_cpt_nonanginal, label_cpt_atypical, label_cpt_typical and
label_cpt_unknown.
The value of variable in the parameters label_have_dyspnoea_no,
label_have_dyspnoea_yes and label_have_dyspnoea_unknown.
The value of variable in the parameters
label_have_family_history_no, label_have_family_history_yes
and label_have_family_history_unknown.
The value of variable in the parameters
label_have_smoking_history_no, label_have_smoking_history_yes
and label_have_smoking_history_unknown.
The value of variable in the parameters
label_have_dyslipidemia_no, label_have_dyslipidemia_yes
and label_have_dyslipidemia_unknown.
The value of variable in the parameters
label_have_hypertension_no, label_have_hypertension_yes
and label_have_hypertension_unknown.
The value of variable in the parameters
label_have_diabetes_no, label_have_diabetes_yes
and label_have_diabetes_unknown.
Input non-negative numeric to indicate the total coronary calcium score of the patient.
A logical evaluating to TRUE or FALSE indicating whether we can
allow chest_pain_type or have_dyspnoea to be NA when calculating the score
Input integer 0 to 5 to indicate the maximum number of
missing risk factors to tolerate before outputting an NA.
Default: 0
Label(s) for definition(s) of male sex.
Default: c("male")
Label(s) for definition(s) of female sex.
Default: c("female")
Label(s) for definition(s) of missing sex.
Default: c(NA, NaN)
Label(s) for patient having no dyspnoea symptoms.
Default: c("no")
Label(s) for patient having dyspnoea symptoms.
Default: c("yes")
Label(s) for patient having unknown dyspnoea symptoms.
Default: c(NA, NaN)
Label(s) for patient having no chest pain.
Default: c("no chest pain")
Label(s) for patient having nonanginal or non-specific chest pain.
Default: c("nonanginal")
Label(s) for patient having atypical chest pain.
Default: c("atypical")
Label(s) for patient having typical chest pain.
Default: c("typical")
Label(s) for patient having unknown chest pain type symptoms.
Default: c(NA, NaN)
Label(s) for patient with no family history of CAD.
Default: c("no")
Label(s) for patient having family history of CAD.
Default: c("yes")
Label(s) for patient
having unknown family history of CAD.
Default: c(NA, NaN)
Label(s) for patient with
no smoking history (current or past).
Default: c("no")
Label(s) for patient having
smoking history (current or past).
Default: c("yes")
Label(s) for patient
having unknown smoking history (current or past).
Default: c(NA, NaN)
Label(s) for patient with no dyslipidemia.
Default: c("no")
Label(s) for patient having dyslipidemia.
Default: c("yes")
Label(s) for patient
having unknown dyslipidemia.
Default: c(NA, NaN)
Label(s) for patient with no hypertension.
Default: c("no")
Label(s) for patient having hypertension.
Default: c("yes")
Label(s) for patient
having unknown hypertension.
Default: c(NA, NaN)
Label(s) for patient with no diabetes.
Default: c("no")
Label(s) for patient having diabetes.
Default: c("yes")
Label(s) for patient
having unknown diabetes.
Default: c(NA, NaN)
The predictive model is based on > 40000 symptomatic patients from 2008 to 2017 from 13 hospitals in Western Denmark. These patients are registered under the Western Denmark Heart Registry.
# 40 year old Male with nonanginal chest pain and coronary calcium score of 0
calculate_winther_2020_cacs_cl_ptp(
age = 40,
sex = "male",
chest_pain_type = "no chest pain",
have_dyspnoea = "no",
have_family_history = "no",
have_smoking_history = "no",
have_dyslipidemia = "no",
have_hypertension = "no",
have_diabetes = "no",
coronary_calcium_score = 0,
allow_na_symptom_score = TRUE,
max_na_num_of_rf = 0
)
Run the code above in your browser using DataLab