powered by
Add a quote around characters.
chr_quoted(chr, type = "`")
A character vector with quotes added in each element. (e.g. c("`a`", "`b`", "`c`")).
A character vector to add quotes in each element. (e.g. c("a", "b", "c")).
Character to be used as a quote. Default: '`'
DETAILS
chr_quoted(c("a","b", "c"))
Run the code above in your browser using DataLab